==> GameboyAdvanceVM-Project-0.01.zip: win32/MainFrm.h <==
// MainFrm.h : CMainFrame NX̐錾уC^[tFCX̒`܂B
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_MAINFRM_H__157A770E_4147_4F0A_9DF9_6D1C523F1E5B__INCLUDED_)
#define AFX_MAINFRM_H__157A770E_4147_4F0A_9DF9_6D1C523F1E5B__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000


#include "ChildView.h"
#include "DisassemblerDlg.h"
#include "RegisterDlg.h"
#include "MemoryDlg.h"
#include "OamDlg.h"
#include "DispcntDlg.h"

class CMainFrame : public CFrameWnd
{
	
public:
	CMainFrame();
	static UINT ThreadMain(LPVOID pParam);
	int AgbRomOpen(char *filename);
	int exec_arm_state();
	void WaitForTMain();
	void StepExecute();
	void UpdateDebugger();
	void Mainloop();
	CDisassemblerDlg *m_pDisassemblerDlg;
	CRegisterDlg *m_pRegisterDlg;
	CMemoryDlg *m_pMemoryDlg;
	COamDlg *m_pOamDlg;
	CDispcntDlg *m_pDispcntDlg;
	BOOL fTMain;

protected: 
	DECLARE_DYNAMIC(CMainFrame)
	CWinThread* m_pTMain;

// Agr[g
public:

// Iy[V
public:

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CMainFrame)
	public:
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	virtual BOOL OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo);
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	//}}AFX_VIRTUAL

// Cve[V
public:
	virtual ~CMainFrame();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif
	CChildView    m_wndView;

// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CMainFrame)
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnSetFocus(CWnd *pOldWnd);
	afx_msg void OnOpen();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnPaint();
	afx_msg void OnReset();
	afx_msg void OnRun();
	afx_msg void OnShowDisassembler();
	afx_msg void OnShowRegister();
	afx_msg void OnShowMemory();
	afx_msg void OnNext();
	afx_msg void OnStop();
	afx_msg void OnClose();
	afx_msg void OnAutoUpdate();
	afx_msg void OnZoom1();
	afx_msg void OnZoom2();
	afx_msg void OnZoom3();
	afx_msg void OnZoom4();
	afx_msg void OnZoomFullscreen();
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnShowFps();
	afx_msg void OnVsync();
	afx_msg void OnDropFiles(HDROP hDropInfo);
	afx_msg void OnShowOam();
	afx_msg void OnDestroy();
	afx_msg void OnActivate(UINT nState, CWnd* pWndOther, BOOL bMinimized);
	afx_msg void OnShowDispcnt();
	afx_msg void OnInformation();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MAINFRM_H__157A770E_4147_4F0A_9DF9_6D1C523F1E5B__INCLUDED_)

==> GameboyAdvanceVM-Project-0.02.zip: win32/MainFrm.h <==
// MainFrm.h : CMainFrame NX̐錾уC^[tFCX̒`܂B
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_MAINFRM_H__157A770E_4147_4F0A_9DF9_6D1C523F1E5B__INCLUDED_)
#define AFX_MAINFRM_H__157A770E_4147_4F0A_9DF9_6D1C523F1E5B__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000


#include "ChildView.h"
#include "DisassemblerDlg.h"
#include "RegisterDlg.h"
#include "MemoryDlg.h"
#include "OamDlg.h"
#include "DispcntDlg.h"
#include "TraceDlg.h"
#include "HardioDlg.h"
#include "TileDlg.h"

class CMainFrame : public CFrameWnd
{
	
public:
	CMainFrame();
	static UINT ThreadMain(LPVOID pParam);
	int AgbRomOpen(char *filename);
	int exec_arm_state();
	void exec_arm_clk(int clk);
	void WaitForTMain();
	void StepExecute();
	void UpdateDebugger();
	void agb_mainloop();
	void ShowFps();
	CDisassemblerDlg *m_pDisassemblerDlg;
	CRegisterDlg *m_pRegisterDlg;
	CMemoryDlg *m_pMemoryDlg;
	COamDlg *m_pOamDlg;
	CDispcntDlg *m_pDispcntDlg;
	CHardioDlg *m_pHardioDlg;
	CTileDlg *m_pTileDlg;
	BOOL fTMain;

protected: 
	DECLARE_DYNAMIC(CMainFrame)
	CWinThread* m_pTMain;

// Agr[g
public:

// Iy[V
public:

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CMainFrame)
	public:
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	virtual BOOL OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo);
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	//}}AFX_VIRTUAL

// Cve[V
public:
	virtual ~CMainFrame();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif
	CChildView    m_wndView;

// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CMainFrame)
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnSetFocus(CWnd *pOldWnd);
	afx_msg void OnOpen();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnPaint();
	afx_msg void OnReset();
	afx_msg void OnRun();
	afx_msg void OnShowDisassembler();
	afx_msg void OnShowRegister();
	afx_msg void OnShowMemory();
	afx_msg void OnNext();
	afx_msg void OnStop();
	afx_msg void OnClose();
	afx_msg void OnAutoUpdate();
	afx_msg void OnZoom1();
	afx_msg void OnZoom2();
	afx_msg void OnZoom3();
	afx_msg void OnZoom4();
	afx_msg void OnZoomFullscreen();
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnShowFps();
	afx_msg void OnVsync();
	afx_msg void OnDropFiles(HDROP hDropInfo);
	afx_msg void OnShowOam();
	afx_msg void OnDestroy();
	afx_msg void OnActivate(UINT nState, CWnd* pWndOther, BOOL bMinimized);
	afx_msg void OnShowDispcnt();
	afx_msg void OnInformation();
	afx_msg void OnAutoRun();
	afx_msg void OnShowTrace();
	afx_msg void OnShowHardio();
	afx_msg void OnFrameRate0();
	afx_msg void OnFrameRate1();
	afx_msg void OnFrameRate2();
	afx_msg void OnFrameRate3();
	afx_msg void OnFrameRate4();
	afx_msg void OnFrameRate5();
	afx_msg void OnShowTile();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MAINFRM_H__157A770E_4147_4F0A_9DF9_6D1C523F1E5B__INCLUDED_)
